<?php
/*
 * Plugin name: Grimlock Gallery
 * Plugin URI:  http://www.octopix.be
 * Description: This add on for Grimlock adds a gallery section widget that uses WordPress native gallery.
 * Author:      Themosaurus
 * Author URI:  http://www.themosaurus.com
 * Version:     1.0.6
 * License:     GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: grimlock-gallery
 * Domain Path: /languages
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

define( 'GRIMLOCK_GALLERY_VERSION',              '1.0.6' );
define( 'GRIMLOCK_GALLERY_MIN_GRIMLOCK_VERSION', '1.3.11' );
define( 'GRIMLOCK_GALLERY_PLUGIN_FILE',          __FILE__ );
define( 'GRIMLOCK_GALLERY_PLUGIN_DIR_PATH',      plugin_dir_path( __FILE__ ) );
define( 'GRIMLOCK_GALLERY_PLUGIN_DIR_URL',       plugin_dir_url( __FILE__ ) );

// Initialize update checker
require 'libs/plugin-update-checker/plugin-update-checker.php';
Puc_v4_Factory::buildUpdateChecker(
	'http://files.themosaurus.com/grimlock-gallery/version.json',
	__FILE__,
	'grimlock-gallery'
);

/**
 * Display notice if Grimlock version doesn't match minimum requirement
 */
function grimlock_gallery_dependency_notice() {
	$url = self_admin_url( 'update-core.php?action=do-plugin-upgrade&plugins=' ) . urlencode( plugin_basename( GRIMLOCK_PLUGIN_FILE ) );
	$url = wp_nonce_url( $url, 'upgrade-core' ); ?>
	<div class="notice notice-error">
		<p><?php printf( esc_html__( '%1$sGrimlock Gallery%2$s requires %1$sGrimlock %3$s%2$s to continue running properly. Please %4$supdate Grimlock.%5$s', 'grimlock-gallery' ), '<strong>', '</strong>', GRIMLOCK_GALLERY_MIN_GRIMLOCK_VERSION, '<a href="' . esc_url( $url ) . '">', "</a>" ); ?></p>
	</div>
	<?php
}

/**
 * Load plugin.
 */
function grimlock_gallery_loaded() {
	if ( version_compare( GRIMLOCK_VERSION, GRIMLOCK_GALLERY_MIN_GRIMLOCK_VERSION, '<' ) ) {
		add_action( 'admin_notices', 'grimlock_gallery_dependency_notice' );
		return;
	}

	require_once 'inc/class-grimlock-gallery.php';

	global $grimlock_gallery;
	$grimlock_gallery = new Grimlock_Gallery();

	register_activation_hook( __FILE__,   array( $grimlock_gallery, 'activate' ) );
	register_deactivation_hook( __FILE__, array( $grimlock_gallery, 'deactivate' ) );

	do_action( 'grimlock_gallery_loaded' );
}
add_action( 'grimlock_loaded', 'grimlock_gallery_loaded' );
