<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Grimlock_Gallery
 *
 * @author  octopix
 * @since   1.0.0
 * @package grimlock-gallery/inc
 */
class Grimlock_Gallery {
	/**
	 * Setup class.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		load_plugin_textdomain( 'grimlock-gallery', false, 'grimlock-gallery/languages' );

		require_once GRIMLOCK_GALLERY_PLUGIN_DIR_PATH . 'inc/component/class-grimlock-gallery-section-component.php';

		add_action( 'grimlock_gallery_section', array( $this, 'gallery_section' ), 10, 1 );

		require_once GRIMLOCK_GALLERY_PLUGIN_DIR_PATH . 'inc/widget/class-grimlock-gallery-section-widget.php';
		require_once GRIMLOCK_GALLERY_PLUGIN_DIR_PATH . 'inc/widget/fields/class-grimlock-gallery-section-widget-fields.php';

		require_once GRIMLOCK_GALLERY_PLUGIN_DIR_PATH . 'inc/block/gallery-section/class-grimlock-gallery-section-block.php';

		add_action( 'widgets_init',             array( $this, 'widgets_init'    ), 10    );

		add_action( 'admin_enqueue_scripts',    array( $this, 'admin_enqueue_scripts' ) );
	}

	/**
	 * Display the gallery section component.
	 *
	 * @param array $args
	 * @since 1.0.0
	 */
	public function gallery_section( $args = array() ) {
		$component = new Grimlock_Gallery_Section_Component( apply_filters( 'grimlock_gallery_section_args', $args ) );
		$component->render();
	}

	/**
	 * Register the custom widgets.
	 *
	 * @since 1.0.0
	 */
	public function widgets_init() {
		register_widget( 'Grimlock_Gallery_Section_Widget' );
	}

	/**
	 * Enqueue scripts and stylesheets in admin pages for the widgets.
	 *
	 * @since 1.0.0
	 */
	public function admin_enqueue_scripts() {

		// Enqueue scripts.
		wp_enqueue_media();
		wp_enqueue_script( 'jquery-ui-button' );

		wp_enqueue_script( 'grimlock-gallery-widget', GRIMLOCK_GALLERY_PLUGIN_DIR_URL . 'assets/js/gallery-widget.js', array( 'jquery', 'jquery-ui-button' ), GRIMLOCK_GALLERY_VERSION, true );
	}

	/**
	 * Fired on plugin activation.
	 *
	 * @since 1.0.0
	 */
	public function activate() {}

	/**
	 * Fired on plugin deactivation.
	 *
	 * @since 1.0.0
	 */
	public function deactivate() {}
}