<?php

/**
 * Grimlock_Gallery_Section_Widget_Fields Class
 *
 * @author   Themosaurus
 * @since    1.0.0
 * @package  grimlock
 */
class Grimlock_Gallery_Section_Widget_Fields extends Grimlock_Section_Widget_Fields {

	/**
	 * Setup class
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct( $id_base = 'grimlock_gallery_section_widget' ) {
		parent::__construct( $id_base );

		// General tab
		remove_action( "{$this->id_base}_general_tab", array( $this, 'add_thumbnail_field'      ), 100    );
		remove_action( "{$this->id_base}_general_tab", array( $this, 'add_thumbnail_size_field' ), 100    );
		add_action( "{$this->id_base}_general_tab",    array( $this, 'add_gallery_field'        ), 100, 2 );
	}

	/**
	 * Add a gallery field to set the gallery of the section
	 *
	 * @param array $instance
	 * @param WP_Widget $widget
	 * @since 1.0.0
	 */
	public function add_gallery_field( $instance, $widget ) {
		$args = array(
			'id'    => 'gallery',
			'label' => esc_html__( 'Gallery:', 'grimlock-gallery' ),
			'value' => $instance['gallery'],
		); ?>
		<div class="grimlock_gallery_section_widget-gallery wp-clearfix">

			<div class="grimlock_gallery_section_widget-gallery__title"><?php echo $args['label']; ?></div>
			<input id="<?php echo $widget->get_field_id( $args['id'] ); ?>" name="<?php echo $widget->get_field_name( $args['id'] ); ?>" class="gallery-props" type="hidden" value="<?php echo esc_attr( json_encode( ( $args['value'] ) ) ); ?>" />

			<div class="media-widget-control">
				<div class="gallery <?php echo empty( $args['value'] ) ? 'hidden' : ''; ?>">

				</div><!-- .gallery-image -->

				<div class="media-widget-preview media_gallery">
					<div class="attachment-media-view">
						<p class="placeholder">
							<?php if ( empty( $args['value'] ) ) :
								esc_html_e( 'No images selected' );
							else: ?>
								<span class="spinner" style="float: none; visibility: visible;"></span>
							<?php endif; ?>
						</p>
					</div>
				</div>

				<div class="media-widget-buttons">
					<input type="button" class="button select-media right <?php echo !empty( $args['value'] ) ? 'hidden' : ''; ?>" value="<?php echo empty( $args['value'] ) ? esc_html__( 'Add Images' ) : esc_html__( 'Edit Gallery', 'grimlock-gallery' ); ?>" />
					<br class="clear"/>
				</div><!-- .select-actions -->

			</div><!-- .attachment-media-view -->
			<?php if ( ! empty( $args['description'] ) ) : ?>
				<small style="display: inline-block;"><?php echo $args['description'] ?></small>
			<?php endif; ?>

		</div><!-- .grimlock_gallery_section_widget-image -->
		<?php
	}

	/**
	 * Change the default settings for the widget
	 *
	 * @param array $defaults The default settings for the widget.
	 *
	 * @return array The updated default settings for the widget.
	 */
	public function change_defaults( $defaults ) {
		$defaults = parent::change_defaults( $defaults );

		return array_merge( $defaults, array(
			'gallery' => 0,
		) );
	}

	/**
	 * Change the arguments sent to the component in charge of rendering the widget
	 *
	 * @param array $component_args The arguments for the component in charge of rendering the widget
	 * @param array $instance Settings for the current widget instance.
	 * @param array $widget_args Display arguments including 'before_title', 'after_title',
	 *                           'before_widget', and 'after_widget'.
	 *
	 * @return array The updated arguments for the component in charge of rendering the widget
	 */
	public function change_component_args( $component_args, $instance, $widget_args, $widget_id ) {
		$component_args = parent::change_component_args( $component_args, $instance, $widget_args, $widget_id );

		return array_merge( $component_args, array(
			'gallery' => $instance['gallery'],
		) );
	}

	/**
	 * Handles sanitizing settings for the current widget instance.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 *
	 * @return array Settings to save or bool false to cancel saving.
	 */
	public function sanitize_instance( $new_instance, $old_instance ) {
		$instance = parent::sanitize_instance( $new_instance, $old_instance );

		$instance['gallery'] = isset( $new_instance['gallery'] ) ? json_decode( $new_instance['gallery'], true ) : 0;

		return $instance;
	}

	/**
	 * Get the widget classes
	 *
	 * @param array $instance Settings for the current widget instance.
	 *
	 * @return array The widget classes
	 */
	protected function get_classes( $instance ) {
		$classes   = array( $instance['classes'] );
		$classes[] = "grimlock-gallery-section--{$instance['button_format']}";
		$title     = ! empty( $instance['title'] ) ? sanitize_title( $instance['title'] ) : '';

		if ( '' !== $title ) {
			$classes[] = "grimlock-gallery-section--{$title}";
		}

		return $classes;
	}
}

return new Grimlock_Gallery_Section_Widget_Fields();